SystemOrganization addCategory: #'StyleProfile-Basic-Locator'!
SystemOrganization addCategory: #'StyleProfile-Business-Model'!
SystemOrganization addCategory: #'StyleProfile-DAO'!
SystemOrganization addCategory: #'StyleProfile-View-Web'!
SystemOrganization addCategory: #'StyleProfile-Tests-Basic-Locator'!
SystemOrganization addCategory: #'StyleProfile-Tests-Business-Model'!
SystemOrganization addCategory: #'StyleProfile-Tests-DAO'!
SystemOrganization addCategory: #'StyleProfile-Tests-View-Web'!

TestCase subclass: #AddressTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-Business-Model'!

!AddressTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 21:06'!
testInstantiation

	| address |

	address :=
		Address
			newStreet:  '906 W Clark Street'
			city: 'Urbana'
			state: State IL
			country: 'US'
			zipcode: '61801'.

	self assert: address street equals: '906 W Clark Street'.
	self assert: address city equals: 'Urbana'.
	self assert: address state equals: State IL.
	self assert: address country equals: 'US'.
	self assert: address zipcode equals: '61801'
! !

TestCase subclass: #CategoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-Business-Model'!

!CategoryTest methodsFor: 'tests' stamp: 'IgorArouca 3/24/2013 23:10'!
createFloralCategory

	^ Category newName: #floral description: 'This category is about flowers'! !

!CategoryTest methodsFor: 'tests' stamp: 'IgorArouca 3/24/2013 23:10'!
testCreation

	| floral |

	floral := self createFloralCategory.

	self assert: floral name equals: 'floral'.
	self assert: floral description equals: 'This category is about flowers'! !

!CategoryTest methodsFor: 'tests' stamp: 'IgorArouca 3/24/2013 23:49'!
testCreationDuplicateError

	self createFloralCategory.	

	self should: [ Category newName: #floral description: 'This is a duplicate category' ]
		 raise: Error
		 description: 'A category named #floral already exists'
! !

TestCase subclass: #ConnectionServiceLocatorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-Basic-Locator'!

!ConnectionServiceLocatorTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 20:36'!
connectionSettings

	| settingsDict settingsStream tempStream |

	settingsDict := Dictionary new
		at: #host put: '127.0.0.1';
		at: #port put: '3306';
		at: #database put: 'information_schema';
		at: #user put: 'root';
		at: #password put: '';
		yourself.

	tempStream := String new writeStream.
	settingsDict storeOn: tempStream.

	^ ReadStream on: tempStream contents
! !

!ConnectionServiceLocatorTest methodsFor: 'tests' stamp: 'IgorArouca 3/23/2013 20:54'!
testConnection

	| strategy connection locator result |

	strategy := DBXManualConnectionStrategy newConnectionSettings: self connectionSettings.

	"Sets the default service to connect to the database above"
	locator := ConnectionServiceLocator instance connectionStrategy: strategy.

	"The returned connection is eady to receive queries to be executed agains the db"
	connection := locator connection.

	"Runs a simple query to test connection"
	result := connection execute: 'select * from engines'.

	self assert: result rows isEmpty equals: false. 

	"Closes the connection to release allocated resources"
	connection close
! !

!ConnectionServiceLocatorTest methodsFor: 'tests' stamp: 'IgorArouca 3/23/2013 21:07'!
testConnectionWithoutStrategy

	| locator |

	locator := ConnectionServiceLocator instance.
	locator connectionStrategy: nil.

	self should: [ locator connection ] raise: Error
! !

TestCase subclass: #DAOFactoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-DAO'!

!DAOFactoryTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 22:49'!
testDAONotFoundError

	self	 should: [ DAOFactory dataAccessObjectFor: Object ]
		 raise: Error
		 withExceptionDo: [ :exception |
			self assert: (exception description = 'Error: There is no ObjectDAO in the system.')
		]
! !

!DAOFactoryTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 22:31'!
testDAORetrieval
 
	self assert: (DAOFactory dataAccessObjectFor: User) class equals: UserDAO.
! !

TestCase subclass: #DAOTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-DAO'!

DAOTest subclass: #AddressDAOTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-DAO'!

!AddressDAOTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/23/2013 14:33'!
testCRUD

	| address result |

	address := Address
		newStreet: '906 W Clark Street'
		city: 'Urbana'
		state: State IL
		country: 'US'
		zipcode: '61801'.

	result := AddressDAO instance save: address.
	self assert: result rowsAffected equals: 1.

	result connection disconnect
! !

!AddressDAOTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 21:08'!
testInstalation

	self shouldnt: AddressDAO install raise: Error
! !

!AddressDAOTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/23/2013 00:15'!
testSave

	| address result |

	address := Address
		newStreet: '906 W Clark Street'
		city: 'Urbana'
		state: State IL
		country: 'US'
		zipcode: '61801'.

	result := AddressDAO instance save: address.
	self assert: result rowsAffected equals: 1.

	result connection disconnect
! !

!DAOTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 23:40'!
connection

	^ self subject connection
! !

!DAOTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 23:45'!
rollback

	^ self connection rollback
! !

!DAOTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 23:45'!
startTransaction

	^ self connection startTransaction
! !

!DAOTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/23/2013 00:11'!
subject

	| className daoClass |

	className := self class name.
	daoClass := Smalltalk at: (className wordBefore: (className findString: 'Test') - 1) asSymbol.

	^ daoClass instance
! !

TestCase subclass: #PictureDAOTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-DAO'!

!PictureDAOTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/24/2013 12:24'!
testInstatiation

 
! !

TestCase subclass: #PictureTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-Business-Model'!

!PictureTest commentStamp: '<historical>' prior: 0!
A PictureTest is a test class for testing the behavior of Picture!

!PictureTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 00:14'!
testEmptyPath

	self should: [ 
		Picture newPath: #'' style: #Classic.	
	] raise:  Error withExceptionDo: [ :ex | self assert: ex messageText equals: 'I need a path'].
	
	! !

!PictureTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 00:26'!
testEmptyStyle

	self should: [ 
		Picture newPath: #aPath style: #''.	
	] raise:  Error withExceptionDo: [ :ex | self assert: ex messageText equals: 'I need a style'].
	
	! !

!PictureTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/26/2013 23:55'!
testInstantiation

	| picture |

	picture := Picture newPath: #myPicturePath style: #Classic.
	self assert: picture path equals:  #myPicturePath.
	self assert: picture style equals:  #Classic.
! !

!PictureTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/26/2013 23:16'!
testInstatiation

	Picture newPath: #'myPayh' style: #Modern. ! !

!PictureTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 00:12'!
testWithoutPath

	self should: [ 
		Picture newPath: nil style: #Classic.	
	] raise:  Error withExceptionDo: [ :ex | self assert: ex messageText equals: 'I need a path'].
	
	! !

!PictureTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 00:25'!
testWithoutStyle

	self should: [ 
		Picture newPath: 'aPath' style: nil.	
	] raise:  Error withExceptionDo: [ :ex | self assert: ex messageText equals: 'I need a style'].
	
	! !

TestCase subclass: #QuestionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-Business-Model'!

!QuestionTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 00:55'!
testEmptyOptions

	self should: [ 
		Question newOptions: {}.
	] raise:  Error withExceptionDo: [ :ex | self assert: ex messageText equals: 'I need options'].! !

!QuestionTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 08:44'!
testInstantiation

	|option1 option2 question|

	option1 := Picture newPath: #myPath style: #Classical.
	option2 := Picture newPath: #myPath2 style: #Classical.
	question := Question newOptions: (Array with: option1 with: option2). 

	self assert: question options equals: (Array with: option1 with: option2).! !

!QuestionTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 00:54'!
testWithoutOptions

	self should: [ 
		Question newOptions: nil.
	] raise:  Error withExceptionDo: [ :ex | self assert: ex messageText equals: 'I need options'].! !

TestCase subclass: #StyleTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-Business-Model'!

TestCase subclass: #SurveyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-Business-Model'!

!SurveyTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 16:31'!
setUp

	| counter |

	Picture initializeWith: (Random seed: 42).

	counter := 0.
	#(#Traditional #Natural #Contemporary #Eclectic #Romantic #DIY #Bohemian #Urban) do: [ :style |
		Picture newPath: #'Pic 1' style: style. counter := counter + 1.
		Picture newPath: #'Pic 2' style: style. counter := counter + 1.
		Picture newPath: #'Pic 3' style: style. counter := counter + 1.
	]
! !

!SurveyTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 08:43'!
testExecution

	! !

!SurveyTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 16:32'!
testFirstQuestion

	| question survey result |

	survey := Survey new.

	question := survey nextQuestion.
	self assert: question picture1 style ~= question picture2 style.

	question choose1.
	self assert: question answer equals: question picture1.

	question := survey nextQuestion.
	question choose2.
	self assert: question answer equals: question picture2.

	result := survey result.
	self assert: (result at: #Traditional) equals: 1.
	self assert: (result at: #DIY) equals: 1.
! !

!SurveyTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 10:49'!
testTwoQuestions

	| survey question |

	survey := Survey new.
	survey nextQuestion.
	question := survey nextQuestion.
	self assert: question picture1 style ~= question picture2 style! !

TestCase subclass: #UserDAOTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-DAO'!

!UserDAOTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 00:41'!
testSave

	User new! !

TestCase subclass: #UserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-Business-Model'!

!UserTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 00:34'!
sampleAddress

	Address
		newStreet: '906 W Clark St'
		city: 'Urbana'
		state: #IL
		country: 'USA'
		zipcode: '61801'
! !

!UserTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 23:10'!
testInstatiation

	User
		newFirstName: 'Igor'
		lastName: 'Arouca'
		gender: #M
		age: 31
		educationLevel: #Master
		email: 'arouca2@illinois.edu'
		password: 'a12345678'
		address: self sampleAddress
! !

WAComponent subclass: #WeddingForm
	instanceVariableNames: 'user location'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-View-Web'!

!WeddingForm commentStamp: 'HamidJahani 4/6/2013 19:19' prior: 0!
problems:
in save, gender is not informed correctly.
who is owner of weddingdate and weddingbudget in the form?
should this form create a new user?


Instance Variables:
	user	<UserDAO>
	location	<LocationDAO>!

!WeddingForm class methodsFor: 'as yet unclassified' stamp: 'HamidJahani 4/1/2013 01:29'!
initialize
    WAAdmin register: self asApplicationAt: 'wedform'! !

!WeddingForm methodsFor: 'initialization' stamp: 'HamidJahani 4/1/2013 01:30'!
initialize
   super initialize.! !

!WeddingForm methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 16:09'!
location
	^ location ifNil: [ location := LocationDAO defaultLocation ]
! !

!WeddingForm methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 15:39'!
location: aLocationDAO
	location := aLocationDAO! !

!WeddingForm methodsFor: 'rendering' stamp: 'HamidJahani 4/1/2013 00:49'!
renderButtonsOn: html
	html
		tableData;
		tableData: [ html submitButton on: #save of: self ].! !

!WeddingForm methodsFor: 'rendering' stamp: 'HamidJahani 4/6/2013 18:03'!
renderContentOn: html
	html div
		class: 'generic lightbox';
		with: [ 
					html heading: 'Basic information'.
					html
						form: [ 
							html
								table: [ 
									html
										tableRow: [ self renderUserInputOn: html ];
										tableRow: [ self renderLocationInputOn: html ];
										tableRow: [ self renderButtonsOn: html ] ] ] ]	"

Wedding Date:
Estimated Budget:"! !

!WeddingForm methodsFor: 'rendering' stamp: 'HamidJahani 4/6/2013 16:36'!
renderLocationInputOn: html
	html
		tableRow: [ 
					html
						tableData: [ html text: 'Street Address: ' ];
						tableData: [ html textInput on: #street of: self location ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'City: ' ];
						tableData: [ html textInput on: #city of: self location ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'County: ' ];
						tableData: [ html textInput on: #county of: self location ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'State: ' ];
						tableData: [ html textInput on: #state of: self location ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'Zip Code: ' ];
						tableData: [ html textInput on: #zipcode of: self location ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'Country: ' ];
						tableData: [ 
									html select
										list: ValidCountriesDAO list;
										callback: [ :value | self location country: value ] ] ]! !

!WeddingForm methodsFor: 'rendering' stamp: 'HamidJahani 4/6/2013 18:02'!
renderUserInputOn: html
	| genderGroup |
	genderGroup := html radioGroup.
	html
		tableRow: [ 
					html
						tableData: [ html text: 'First Name: ' ];
						tableData: [ html textInput on: #firstName of: self user ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'Last Name: ' ];
						tableData: [ html textInput on: #lastName of: self user ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'Age: ' ];
						tableData: [ html textInput on: #age of: self user ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'Email: ' ];
						tableData: [ html textInput on: #email of: self user ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'Gender: ' ];
						tableData: [ 
									genderGroup radioButton
										selected: self user isMale;
										callback: [ self user gender: #male ].
									html text: 'Male'.
									genderGroup radioButton
										selected: self user isMale not;
										callback: [ self user gender: #female ].
									html text: 'Female' ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'Education Level: ' ];
						tableData: [ 
									html select
										list: ValidEducationLevelsDAO list;
										callback: [ :value | self user educationLevel: value ] ] ]! !

!WeddingForm methodsFor: 'as yet unclassified' stamp: 'HamidJahani 4/6/2013 17:55'!
save
    "this should change to save the submitted data to database"
    self inform: self user firstName , ', ' , self user lastName , ', ' , self user gender asString , ', ' , self location country! !

!WeddingForm methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 16:07'!
user
	^ user ifNil: [ user := UserDAO defaultUser ]
! !

!WeddingForm methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 14:54'!
user: aUserDAO
	user := aUserDAO! !

Object subclass: #Address
	instanceVariableNames: 'street city state country zipcode'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Business-Model'!

!Address class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 23:54'!
new

	^ self shouldNotImplement
! !

!Address class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 23:54'!
newStreet: street city: city state: state country: country zipcode: zipcode

	^ super new street: street city: city state: state country: country zipcode: zipcode
! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:20'!
city

	^ city
! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:20'!
country

	^ country
! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 00:52'!
printOn: aStream

	aStream
		nextPutAll: street;
		nextPutAll: ', '; 
		nextPutAll: city;
		nextPutAll: ', '; 
		nextPutAll: country;
		nextPutAll: ', '; 
		nextPutAll: zipcode
! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 23:31'!
privateValidadeZipcode: aZipcode

	(aZipcode asString matchesRegex: '\d\d\d\d\d') ifFalse: [
		self error: 'Invalid zipcode: ', aZipcode
	]! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 23:59'!
privateZipcode: aZipcode

	self privateValidadeZipcode: aZipcode.
	zipcode := aZipcode
! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 22:48'!
state

	^ state abbreviation

! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:20'!
street

	^ street
! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 23:57'!
street: aStreet city: aCity state: aState country: aCountry zipcode: aZipcode

	street := aStreet.
	city := aCity.
	state := aState.
	country := aCountry.
	self privateZipcode: aZipcode
! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:21'!
zipcode

	^ zipcode
! !

Object subclass: #BaseDAO
	instanceVariableNames: 'serviceLocator'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-DAO'!

BaseDAO class
	instanceVariableNames: 'uniqueInstance'!

BaseDAO class
	instanceVariableNames: 'uniqueInstance'!

BaseDAO subclass: #AddressDAO
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-DAO'!

!AddressDAO class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 23:16'!
tableSchema

	^ self tableName,
	' (
		`address_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
		`street` varchar(255) DEFAULT NULL,
		`complement` varchar(128) DEFAULT NULL,
		`city` varchar(64) DEFAULT NULL,
		`state` char(2) DEFAULT NULL,
		`country` varchar(64) DEFAULT NULL,
		`zipcode` int(11) unsigned DEFAULT NULL,
		PRIMARY KEY (`address_id`)
	)'
! !

!AddressDAO methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 21:03'!
addresses

	| addresses |

	addresses := OrderedCollection new.

	self execute: ('SELECT * FROM ', self class tableName) andReadResult: [ :resultSet |
		resultSet rowsDo: [ :row |
			addresses add: (
				Address
				newStreet: (row valueNamed: 'street')
				city: (row valueNamed: 'city')
				state: (row valueNamed: 'state')
				country: (row valueNamed: 'country')
				zipcode: (row valueNamed: 'zipcode')
			)
		]
	].

	^ addresses
! !

!AddressDAO methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 23:01'!
save: address

	| insertQuery attributes |

	attributes := Address instVarNames asOrderedCollection.
	insertQuery :=
		'INSERT INTO ', self class tableName, '(', attributes asCommaString, ') ',
		'VALUES (', (self extractValuesFor: attributes from: address) , ')'.

	^ self execute: insertQuery
! !

!BaseDAO class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 17:53'!
connectionSettings

	"ToDo: Read settings from a (XML or TXT) file instead of a string"

	| settingsDict settingsStream tempStream |

	settingsDict := Dictionary new
		at: #host put: '127.0.0.1';
		at: #port put: '3306';
		at: #database put: 'wedlum';
		at: #user put: 'root';
		at: #password put: '';
		yourself.

	tempStream := String new writeStream.
	settingsDict storeOn: tempStream.

	^ ReadStream on: tempStream contents
! !

!BaseDAO class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 17:41'!
connectionStrategy

	^ DBXManualConnectionStrategy newConnectionSettings: self connectionSettings
! !

!BaseDAO class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 16:58'!
install

	self instance execute: 'CREATE TABLE IF NOT EXISTS ', self tableSchema
! !

!BaseDAO class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 22:22'!
instance

	^ uniqueInstance ifNil: [ uniqueInstance := self basicNew initialize ]
! !

!BaseDAO class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 22:23'!
new

	^ self shouldNotImplement
! !

!BaseDAO class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 17:14'!
tableName

	| className |

	className := self class name.
	^  className wordBefore: (className findString: 'DAO') - 1
! !

!BaseDAO class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 16:54'!
tableSchema

	^ self subclassResponsibility
! !

!BaseDAO methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 18:01'!
connection

	^ self serviceLocator connection
! !

!BaseDAO methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 21:02'!
execute: queryString

	^ self connection execute: queryString
! !

!BaseDAO methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 23:31'!
execute: sqlQuery andReadResult: readBlock 

	| result |

	result := readBlock value: (self execute: sqlQuery).
	self connection disconnect.

	^ result
! !

!BaseDAO methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 23:01'!
extractValuesFor: attributes from: businessObject

	| value |

	^ (attributes collect: [ :attribute |
		(businessObject perform: attribute asSymbol) asDbxString.
	]) asCommaString
! !

!BaseDAO methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 17:37'!
initialize

	super initialize.
	self initializeServiceLocator.! !

!BaseDAO methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 18:10'!
initializeServiceLocator

	serviceLocator := ConnectionServiceLocator instance connectionStrategy: self class connectionStrategy! !

!BaseDAO methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 18:11'!
serviceLocator

	(serviceLocator isNil or: [ serviceLocator connectionStrategy isNil ]) ifTrue: [
		self initializeServiceLocator
	].

	^ serviceLocator
! !

BaseDAO subclass: #PictureDAO
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-DAO'!

Object subclass: #Category
	instanceVariableNames: 'name description'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Business-Model'!

!Category class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/24/2013 13:20'!
newName: aName description: aDescription

	^ super new privateName: aName description: aDescription
! !

!Category methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/24/2013 23:50'!
checkIfNameIsUnique: aName

	((self class all collect: [ :category | category name ]) includes: aName) ifTrue: [ ^ self ]

	self error: 'A category named ', aName, ' alredy exists.'
! !

!Category methodsFor: 'accessing' stamp: 'HamidJahani 3/24/2013 14:44'!
description 
	^ description ! !

!Category methodsFor: 'accessing' stamp: 'HamidJahani 3/24/2013 14:44'!
name
	^ name! !

!Category methodsFor: 'private' stamp: 'IgorArouca 3/24/2013 23:39'!
privateName: aName

	aName isEmptyOrNil ifTrue: [ ^ self error: 'A category needs a name' ].

	self checkIfNameIsUnique: aName.

	name := aName asSymbol
! !

!Category methodsFor: 'private' stamp: 'HamidJahani 3/24/2013 14:42'!
privateName: aName description: aDescription

	self privateName: aName.
	description := aDescription
! !

Object subclass: #ConnectionServiceLocator
	instanceVariableNames: 'connectionStrategy'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Basic-Locator'!

ConnectionServiceLocator class
	instanceVariableNames: 'uniqueInstance connectionSettings'!

ConnectionServiceLocator class
	instanceVariableNames: 'uniqueInstance connectionSettings'!

!ConnectionServiceLocator class methodsFor: 'instance creation' stamp: 'IgorArouca 3/14/2013 08:58'!
instance

	^ uniqueInstance ifNil: [ uniqueInstance := self basicNew initialize ]
! !

!ConnectionServiceLocator class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/26/2013 22:40'!
new

	^ self shouldNotImplement
! !

!ConnectionServiceLocator methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:47'!
connection

	connectionStrategy ifNil: [
		^ self error: 'Please use the #connectionStrategy: method to tell me how I should get a connection for you'
	].

	^ connectionStrategy connection
! !

!ConnectionServiceLocator methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 18:07'!
connectionStrategy

	^ connectionStrategy
! !

!ConnectionServiceLocator methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:16'!
connectionStrategy: aConnectionStrategy

	connectionStrategy := aConnectionStrategy
! !

Object subclass: #ConnectionStrategy
	instanceVariableNames: 'connectionSettings'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Basic-Locator'!

!ConnectionStrategy class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 18:33'!
newConnectionSettings: aStream

	^ super new connectionSettings: (self privateRetrieveConnectionSettingsDictionaryFrom: aStream)
! !

!ConnectionStrategy class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 17:54'!
privateRetrieveConnectionSettingsDictionaryFrom: aStream
	"This method encapsulates the reading operation from the stream, which should follow the format defined by the input file used to store the connecion settings. It will change after the file format is defined"
	
	^ Dictionary readFrom: aStream
! !

!ConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 16:48'!
connection

	^ self subclassResponsibility
! !

!ConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 18:28'!
connectionSettings: aDictionary

	connectionSettings := aDictionary
! !

ConnectionStrategy subclass: #DBXManualConnectionStrategy
	instanceVariableNames: 'service'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Basic-Locator'!

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 17:57'!
connection

	| connection |

	connection := DBXConnection platform: DBXMySQLBackend new settings: self connectionSettings.
	connection connect.
	connection open.

	^ connection
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:55'!
connectionSettings

	^ DBXConnectionSettings
		host: self host
		port: self port
		database: self database
		userName: self user
		userPassword: self password
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:53'!
database

	^ connectionSettings at: #database
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:53'!
host

	^ connectionSettings at: #host
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:53'!
password

	^ connectionSettings at: #password
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:54'!
port

	^ connectionSettings at: #port
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 17:59'!
user

	^ connectionSettings at: #user
! !

Object subclass: #DAOFactory
	instanceVariableNames: 'dataAccessObjects'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-DAO'!

DAOFactory class
	instanceVariableNames: 'uniqueInstance'!

DAOFactory class
	instanceVariableNames: 'uniqueInstance'!

!DAOFactory class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 22:25'!
dataAccessObjectFor: aClass

	| associatedDAO |

	associatedDAO := (aClass name , 'DAO') asSymbol.
	^ (Smalltalk
		at: associatedDAO
		ifAbsent: [ self error: 'There is no ', associatedDAO, ' in the system.' ]
	) instance
! !

Object subclass: #Picture
	instanceVariableNames: 'path style tags'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Business-Model'!

Picture class
	instanceVariableNames: 'pictures randomPicker'!

Picture class
	instanceVariableNames: 'pictures randomPicker'!

!Picture class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 19:58'!
all

	pictures ifNil: [ self initialize ].

	^ pictures
! !

!Picture class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 11:31'!
initialize

	self initializeWith: Random new
! !

!Picture class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 16:33'!
initializeWith: aRandomPicker

	randomPicker := aRandomPicker.
	pictures := OrderedCollection new
! !

!Picture class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 20:29'!
loadPictureFromFile: tabDelimitedTextFile setPath: picturePath andStyle: pictureStyle 

	| dict count attributeLine cleanedField picture tag |

	dict := IdentityDictionary new.

	FileStream
		readOnlyFileNamed: tabDelimitedTextFile
		do: [ :stream |
			count := 0.
			stream contents linesDo: [ :line |
				(line findString: 'Image') == 0 ifTrue: [
					attributeLine := OrderedCollection new: 3. 
					line tabDelimitedFieldsDo: [ :field |
						cleanedField := field trimBoth capitalized asSymbol.
						cleanedField isEmpty ifFalse: [ attributeLine add: cleanedField ].
					].
					attributeLine isEmpty ifFalse: [ dict at: count put: attributeLine ].
				].
				count := count + 1.
			]
	].

	picture := Picture newPath: picturePath style: pictureStyle.
	dict valuesDo: [ :tagInfo |
		tag := Tag newName: (tagInfo at: 1) category: (tagInfo at: 2).
		picture tag: tag level: (tagInfo at: 3)
	]
! !

!Picture class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 00:28'!
new

	^ self shouldNotImplement.! !

!Picture class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 20:27'!
newPath: aPath style: aStyle 

	^ self all add: (super new privatePath: aPath style: aStyle)
! !

!Picture class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 20:27'!
pickOne

	^ self all atRandom: randomPicker

! !

!Picture class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 20:25'!
resetPicturePool

	pictures := nil
! !

!Picture methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 20:48'!
initialize

	tags := IdentityDictionary new
! !

!Picture methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/26/2013 23:53'!
path

	^ path.
! !

!Picture methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 20:43'!
printOn: aStream

	aStream
		nextPutAll: '(';
		nextPutAll: self style;
		nextPutAll: ') ';
		nextPutAll: self path
! !

!Picture methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 00:22'!
privatePath: aPath 

	(aPath isNil or: [ aPath isEmpty ]) ifTrue: [ self error: 'I need a path' ].

	path := aPath.
! !

!Picture methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 00:23'!
privatePath: aPath style: aStyle 

	self privatePath: aPath.
	
	self privateStyle: aStyle.
! !

!Picture methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 00:22'!
privateStyle: aStyle 
	
	(aStyle isNil or: [ aStyle isEmpty ]) ifTrue: [ self error: 'I need a style' ].

	style := aStyle.
! !

!Picture methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/26/2013 23:53'!
style

	^ style.
! !

!Picture methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 20:19'!
tag: tag level: level

	(level == #Primary or: [ level == #Secondary ]) ifFalse: [
		self error: 'Invalid level: it should be either #Primary or #Secondary'
	].

	self tags at: level put: tag
! !

!Picture methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 20:47'!
tags

	^ tags values
! !

Object subclass: #Question
	instanceVariableNames: 'picture1 picture2 answer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Business-Model'!

!Question class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 01:04'!
newOptions: options

	^ super new privateOptions: options
! !

!Question methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 10:58'!
answer

	^ answer
! !

!Question methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 11:01'!
choose1

	answer := self picture1
! !

!Question methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 11:01'!
choose2

	answer := self picture2
! !

!Question methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 10:33'!
picture1

	^ picture1 ifNil: [ picture1 := Picture pickOne ]
! !

!Question methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 10:57'!
picture2

	picture2 isNil ifFalse: [ ^ picture2 ].

	[
		picture2 := Picture pickOne.
		self picture1 style =  picture2 style

	] whileTrue: [ ].

	^ picture2
! !

Object subclass: #State
	instanceVariableNames: 'abbreviation name'
	classVariableNames: 'AK AL AR AZ CA CO CT DE FL GA HI IA ID IL IN KS KY LA MA MD ME MI MN MO MS MT NC ND NE NH NJ NM NV NY OH OK OR PA RI SC SD TN TX UT VA VT WA WI WV WY'
	poolDictionaries: ''
	category: 'StyleProfile-Business-Model'!

!State class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:03'!
abbreviation: aSymbol name: aString

	| state |

	state := super new privateAbbreviation: aSymbol name: aString.

	(self classPool includesKey: aSymbol) ifFalse: [ self addClassVarNamed: aSymbol ].

	^ self classPool at: aSymbol put: state
! !

!State class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 11:53'!
abbreviations

	^ self classPool keys sort
! !

!State class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:10'!
doesNotUnderstand: aMessage

	^ self classPool at: aMessage selector asUppercase asSymbol
! !

!State class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 10:59'!
initialize

	super initialize.
	self initializeStates
! !

!State class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 11:59'!
initializeStates

	self abbreviation: #AL name: 'Alabama'.
	self abbreviation: #AK name: 'Alaska'.
	self abbreviation: #AZ name: 'Arizona'.
	self abbreviation: #AR name: 'Arkansas'.
	self abbreviation: #CA name: 'California'.
	self abbreviation: #CO name: 'Colorado'.
	self abbreviation: #CT name: 'Connecticut'.
	self abbreviation: #DE name: 'Delaware'.
	self abbreviation: #FL name: 'Florida'.
	self abbreviation: #GA name: 'Georgia'.
	self abbreviation: #HI name: 'Hawaii'.
	self abbreviation: #ID name: 'Idaho'.
	self abbreviation: #IL name: 'Illinois'.
	self abbreviation: #IN name: 'Indiana'.
	self abbreviation: #IA name: 'Iowa'.
	self abbreviation: #KS name: 'Kansas'.
	self abbreviation: #KY name: 'Kentucky'.
	self abbreviation: #LA name: 'Louisiana'.
	self abbreviation: #ME name: 'Maine'.
	self abbreviation: #MD name: 'Maryland'.
	self abbreviation: #MA name: 'Massachusetts'.
	self abbreviation: #MI name: 'Michigan'.
	self abbreviation: #MN name: 'Minnesota'.
	self abbreviation: #MS name: 'Mississippi'.
	self abbreviation: #MO name: 'Missouri'.
	self abbreviation: #MT name: 'Montana'.
	self abbreviation: #NE name: 'Nebraska'.
	self abbreviation: #NV name: 'Nevada'.
	self abbreviation: #NH name: 'New Hampshire'.
	self abbreviation: #NJ name: 'New Jersey'.
	self abbreviation: #NM name: 'New Mexico'.
	self abbreviation: #NY name: 'New York'.
	self abbreviation: #NC name: 'North Carolina'.
	self abbreviation: #ND name: 'North Dakota'.
	self abbreviation: #OH name: 'Ohio'.
	self abbreviation: #OK name: 'Oklahoma'.
	self abbreviation: #OR name: 'Oregon'.
	self abbreviation: #PA name: 'Pennsylvania'.
	self abbreviation: #RI name: 'Rhode Island'.
	self abbreviation: #SC name: 'South Carolina'.
	self abbreviation: #SD name: 'South Dakota'.
	self abbreviation: #TN name: 'Tennessee'.
	self abbreviation: #TX name: 'Texas'.
	self abbreviation: #UT name: 'Utah'.
	self abbreviation: #VT name: 'Vermont'.
	self abbreviation: #VA name: 'Virginia'.
	self abbreviation: #WA name: 'Washington'.
	self abbreviation: #WV name: 'West Virginia'.
	self abbreviation: #WI name: 'Wisconsin'.
	self abbreviation: #WY name: 'Wyoming'
! !

!State class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 11:58'!
names

	^ (self classPool values collect: [ :state | state name ]) sort
! !

!State class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 11:02'!
new

	^ self shouldNotImplement
! !

!State methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 11:57'!
abbreviation

	^ abbreviation
! !

!State methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 11:57'!
name

	^ name
! !

!State methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:15'!
printOn: aStream

	aStream nextPutAll: self name; nextPutAll: ' ('; nextPutAll: self abbreviation; nextPutAll: ')'
! !

!State methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 11:03'!
privateAbbreviation: aSymbol name: aString

	abbreviation := aSymbol.
	name := aString
! !

Object subclass: #Style
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Business-Model'!

!Style class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/24/2013 12:33'!
new

	^ self error: 'I need a name and description. Please use method #newName:descroption: instead.'
! !

!Style class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/24/2013 13:01'!
newName: aName description: aDescription category: aCategory

! !

Object subclass: #Survey
	instanceVariableNames: 'result questions'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Business-Model'!

!Survey methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 11:13'!
nextQuestion

	^ self questions add: Question new! !

!Survey methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 11:14'!
questions

	^ questions ifNil: [ questions := OrderedCollection new ]
! !

!Survey methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/27/2013 11:25'!
result

	| style |

	result := IdentityDictionary new.

	self questions
		do: [ :question | 	
			style := question answer style.
			result at: style ifAbsentPut: [ 0 ].
			result at: style put: (result at: style) + 1
		].

	^ result
! !

Object subclass: #Tag
	instanceVariableNames: 'name category level'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Business-Model'!

Tag class
	instanceVariableNames: 'tags'!

Tag class
	instanceVariableNames: 'tags'!

!Tag class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 15:57'!
all

	^ tags ifNil: [ tags := Set new ]
! !

!Tag class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 15:13'!
new

	^ self shouldNotImplement
! !

!Tag class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 15:56'!
newName: aName category: aCategory

	^ self all add: (super new name: aName category: aCategory)
! !

!Tag class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 20:25'!
resetTagPool

	^ tags := nil
! !

!Tag methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 15:23'!
= aTag

	aTag ifNil: [ ^ false ].
	(aTag isKindOf: Tag) ifFalse: [ ^false ].

	self name ~= aTag name ifTrue: [ ^ false ].
	self category ~= aTag category ifTrue: [ ^ false ].

	^ true
! !

!Tag methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 15:50'!
category

	^ category
! !

!Tag methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 15:49'!
name

	^ name
! !

!Tag methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 15:56'!
name: aName category: aCategory

	name := aName.
	category := aCategory
! !

!Tag methodsFor: 'as yet unclassified' stamp: 'IgorArouca 5/8/2013 20:40'!
printOn: aStream

	aStream
		nextPutAll: self name;
		nextPutAll: ' (';
		nextPutAll: self category;
		 nextPutAll: ')'
! !

Object subclass: #Test
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Business-Model'!

Object subclass: #User
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Business-Model'!

Object subclass: #WeddingFormTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-View-Web'!
State initialize!
WeddingForm initialize!
Picture initialize!
